@@ -35,31 +35,34 @@ class RolesV3TestJSON(base.BaseIdentityV3AdminTest):
     @classmethod
     def resource_setup(cls):
         super(RolesV3TestJSON, cls).resource_setup()
+        prefix = CONF.resource_name_prefix
         cls.roles = list()
         for _ in range(3):
-            role_name = data_utils.rand_name(name='role')
+            role_name = data_utils.rand_name(name='role', prefix=prefix)
             role = cls.roles_client.create_role(name=role_name)['role']
             cls.addClassResourceCleanup(cls.roles_client.delete_role,
                                         role['id'])
             cls.roles.append(role)
-        u_name = data_utils.rand_name('user')
+        u_name = data_utils.rand_name(name='user', prefix=prefix)
         u_desc = '%s description' % u_name
         u_email = '%s@testmail.tm' % u_name
         cls.u_password = data_utils.rand_password()
         cls.domain = cls.create_domain()
         cls.project = cls.projects_client.create_project(
-            data_utils.rand_name('project'),
-            description=data_utils.rand_name('project-desc'),
+            data_utils.rand_name(name='project', prefix=prefix),
+            description=data_utils.rand_name(
+                name='project-desc', prefix=prefix),
             domain_id=cls.domain['id'])['project']
         cls.addClassResourceCleanup(cls.projects_client.delete_project,
                                     cls.project['id'])
         cls.group_body = cls.groups_client.create_group(
-            name=data_utils.rand_name('Group'), project_id=cls.project['id'],
+            name=data_utils.rand_name(name='Group', prefix=prefix),
+            project_id=cls.project['id'],
             domain_id=cls.domain['id'])['group']
         cls.addClassResourceCleanup(cls.groups_client.delete_group,
                                     cls.group_body['id'])
         cls.role = cls.roles_client.create_role(
-            name=data_utils.rand_name('Role'))['role']
+            name=data_utils.rand_name(name='Role', prefix=prefix))['role']
         cls.addClassResourceCleanup(cls.roles_client.delete_role,
                                     cls.role['id'])
         if not CONF.identity_feature_enabled.immutable_user_source:
@@ -78,13 +81,15 @@ class RolesV3TestJSON(base.BaseIdentityV3AdminTest):
     @decorators.idempotent_id('18afc6c0-46cf-4911-824e-9989cc056c3a')
     def test_role_create_update_show_list(self):
         """Test creating, updating, showing and listing a role"""
-        r_name = data_utils.rand_name('Role')
+        r_name = data_utils.rand_name(
+            name='Role', prefix=CONF.resource_name_prefix)
         role = self.roles_client.create_role(name=r_name)['role']
         self.addCleanup(self.roles_client.delete_role, role['id'])
         self.assertIn('name', role)
         self.assertEqual(role['name'], r_name)
 
-        new_name = data_utils.rand_name('NewRole')
+        new_name = data_utils.rand_name(
+            name='NewRole', prefix=CONF.resource_name_prefix)
         updated_role = self.roles_client.update_role(role['id'],
                                                      name=new_name)['role']
         self.assertIn('name', updated_role)
@@ -371,7 +376,8 @@ class RolesV3TestJSON(base.BaseIdentityV3AdminTest):
     def test_domain_roles_create_delete(self):
         """Test creating, listing and deleting domain roles"""
         domain_role = self.roles_client.create_role(
-            name=data_utils.rand_name('domain_role'),
+            name=data_utils.rand_name(
+                name='domain_role', prefix=CONF.resource_name_prefix),
             domain_id=self.domain['id'])['role']
         self.addCleanup(
             test_utils.call_and_ignore_notfound_exc,
