@@ -37,7 +37,7 @@ class RegistryFixture(fixtures.Fixture):
     def __init__(self):
         """Initialise the registry fixture"""
         self.services = set(['compute', 'identity.v2', 'identity.v3',
-                             'image.v1', 'image.v2', 'network', 'placement',
+                             'image.v2', 'network', 'placement',
                              'volume.v2', 'volume.v3', 'object-storage'])
 
     def _setUp(self):
